@@ -209,6 +209,9 @@ def __run_compare(source_file_path, target_path, ref_vocab_file_path, ref_model_
 
 
 def main(argv=None):
+    proquo_description = 'ProQuo is a tool for the detection of short quotations (<= 4 words) between two texts, a' \
+                         ' source text and a target text. The target text is the text quoting the source text.' \
+                         ' Quotations in the target text need to be clearly marked with quotations marks.'
     train_description = 'ProQuo train allows the user to train their own models.'
     train_reference_description = 'ProQuo train reference allows the user to train their own reference model.'
     train_relation_description = 'ProQuo train relation allows the user to train their own relation model.'
@@ -224,8 +227,7 @@ def main(argv=None):
                           ' source text and a target text. The target text is the text quoting the source text.' \
                           ' Quotations in the target text need to be clearly marked with quotations marks.'
 
-    argument_parser = ArgumentParser(prog='proquo', description='ProQuo is a tool to find short quotations (<= 4 words)'
-                                                                ' in texts.')
+    argument_parser = ArgumentParser(prog='proquo', description=proquo_description)
 
     subparsers_command = argument_parser.add_subparsers(dest='command')
     subparsers_command.required = True
@@ -371,7 +373,7 @@ def main(argv=None):
 
             __train_reference(train_file_path, val_file_path, output_folder_path)
 
-        elif args.train_step == 'relation':
+        elif args.train_model == 'relation':
             train_file_path = args.train_file_path[0]
             val_file_path = args.val_file_path[0]
             output_folder_path = args.output_folder_path[0]
@@ -418,7 +420,7 @@ def main(argv=None):
         create_dated_subfolder = args.create_dated_subfolder
         parallel_print_files = args.parallel_print_files
         export_text = args.export_text
-        export_ref = args.export.ref
+        export_ref = args.export_ref
         output_type = args.output_type
         csv_sep = bytes(args.csv_sep, "utf-8").decode("unicode_escape")
 
