@@ -119,14 +119,14 @@ class ProQuo:
             match_len = len(sq.quote.text.split())
 
             if match_len == 1:
-                quote_source_start = self.__search_single_word(sq.quote, source_text, start, end, page_known_pos)
+                quote_source_start, quote_source_end = self.__search_single_word(sq.quote, source_text, start, end,
+                                                                                 page_known_pos)
             else:
-                quote_source_start = self.__search_multi_word(short_matches, sq, start, end, source_text)
+                quote_source_start, quote_source_end = self.__search_multi_word(short_matches, sq, start, end,
+                                                                                source_text)
 
             if quote_source_start > -1:
-                quote_source_end = quote_source_start + len(sq.quote.text)
-                quote_source_text = ''
-
+                quote_source_text = source_text[quote_source_start:quote_source_end]
                 source_span = MatchSpan(quote_source_start, quote_source_end, quote_source_text)
                 target_span = MatchSpan(sq.quote.start, sq.quote.end, sq.quote.text)
                 match = MatchRef(source_span, target_span, sq.reference)
@@ -168,7 +168,6 @@ class ProQuo:
                                                                                 source_text)
 
             if quote_source_start > -1:
-                # quote_source_end = quote_source_start + len(sq.quote.text)
                 quote_source_text = source_text[quote_source_start:quote_source_end]
 
                 source_span = MatchSpan(quote_source_start, quote_source_end, quote_source_text)
